==> ejc-bfyjerp-impl-3.0.0-20250304.013141-165-sources.jar: com/ejianc/business/oa/mapper/InstoreDetailMapper.java <==
package com.ejianc.business.oa.mapper;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Constants;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.business.oa.vo.InstoreDetailVO;
import org.apache.ibatis.annotations.Mapper;

import com.ejianc.framework.skeleton.template.BaseCrudMapper;
import com.ejianc.business.oa.bean.InstoreDetailEntity;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 人力行政-资产入库单子表
 * 
 * @author generator
 * 
 */
@Mapper
public interface InstoreDetailMapper extends BaseCrudMapper<InstoreDetailEntity> {

    Long queryStoreCanUseNumPageDataCount(@Param("searchText") String searchText,
//                                          String outDate,
                                          @Param("storeId") Long storeId,
                                          @Param("materialTypeName")  String materialTypeName, @Param("materialName") String materialName, @Param("materialSpec") String materialSpec,  @Param("materialUnit") String materialUnit
    );

    List<InstoreDetailVO> queryStoreCanUseNumPageData(@Param("searchText") String searchText,
//                                                        @Param("outDate") String outDate,
                                                        @Param("storeId") Long storeId,
                                                        @Param("startLine") Integer startLine,
                                                        @Param("pageSize") Integer pageSize,
                                                        @Param("materialTypeName")  String materialTypeName, @Param("materialName") String materialName, @Param("materialSpec") String materialSpec,  @Param("materialUnit") String materialUnit);

    List<InstoreDetailVO> queryStoreData(Page pages, @Param(Constants.WRAPPER) QueryWrapper queryWrapper);
}

==> ejc-bfyjerp-impl-3.0.0-20251110.043706-304-sources.jar: com/ejianc/business/oa/mapper/InstoreDetailMapper.java <==
package com.ejianc.business.oa.mapper;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Constants;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.business.oa.vo.InstoreDetailVO;
import org.apache.ibatis.annotations.Mapper;

import com.ejianc.framework.skeleton.template.BaseCrudMapper;
import com.ejianc.business.oa.bean.InstoreDetailEntity;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 人力行政-资产入库单子表
 * 
 * @author generator
 * 
 */
@Mapper
public interface InstoreDetailMapper extends BaseCrudMapper<InstoreDetailEntity> {

    Long queryStoreCanUseNumPageDataCount(@Param("searchText") String searchText,
//                                          String outDate,
                                          @Param("storeId") Long storeId,
                                          @Param("materialTypeName")  String materialTypeName, @Param("materialName") String materialName, @Param("materialSpec") String materialSpec,  @Param("materialUnit") String materialUnit
    );

    List<InstoreDetailVO> queryStoreCanUseNumPageData(@Param("searchText") String searchText,
//                                                        @Param("outDate") String outDate,
                                                        @Param("storeId") Long storeId,
                                                        @Param("startLine") Integer startLine,
                                                        @Param("pageSize") Integer pageSize,
                                                        @Param("materialTypeName")  String materialTypeName, @Param("materialName") String materialName, @Param("materialSpec") String materialSpec,  @Param("materialUnit") String materialUnit);
    Long queryStoreCanUseNumPageDataCountAll(@Param("searchText") String searchText,
//                                          String outDate,
                                          @Param("storeId") Long storeId,
                                          @Param("materialTypeName")  String materialTypeName
            , @Param("materialName") String materialName, @Param("materialSpec") String materialSpec,  @Param("materialUnit") String materialUnit
            ,  @Param("materialId") Long materialId
    );

    List<InstoreDetailVO> queryStoreCanUseNumPageDataAll(@Param("searchText") String searchText,
//                                                        @Param("outDate") String outDate,
                                                        @Param("storeId") Long storeId,
                                                        @Param("startLine") Integer startLine,
                                                        @Param("pageSize") Integer pageSize,
                                                        @Param("materialTypeName")  String materialTypeName, @Param("materialName") String materialName
            , @Param("materialSpec") String materialSpec,  @Param("materialUnit") String materialUnit,  @Param("materialId") Long materialId);

    List<InstoreDetailVO> queryStoreData(Page pages, @Param(Constants.WRAPPER) QueryWrapper queryWrapper);
}
